Welcome to carbatpy's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   fluid_props
   components
   heat_pump_simple_v2
   fluid_mixture_search
   utilities
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Dependencies: You should have bought a Version of REFPROP 10.0 (NIST), 
we need the ctREFPROP.dll library. CoolProp should be installed. 
Besides, numpy, scipy and pandas are used.